@@ -24,13 +24,13 @@
 
 #include "holidayregion.h"
 
-#include <QtCore/QDateTime>
-#include <QtCore/QDirIterator>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QSharedData>
-#include <QtCore/QStandardPaths>
-#include <QtCore/QCoreApplication>
+#include <QDateTime>
+#include <QDirIterator>
+#include <QFile>
+#include <QFileInfo>
+#include <QSharedData>
+#include <QStandardPaths>
+#include <QCoreApplication>
 
 #include "holiday_p.h"
 #include "parsers/plan2/holidayparserdriverplan_p.h"
@@ -130,7 +130,7 @@ QStringList HolidayRegion::regionCodes()
         regionCodesList.append(filename.mid(filename.lastIndexOf(QLatin1String("holiday_")) + 8));
     }
 
-    qSort(regionCodesList);
+    std::sort(regionCodesList.begin(), regionCodesList.end());
     return regionCodesList;
 }
 
@@ -408,12 +408,12 @@ QString HolidayRegion::defaultRegionCode(const QString &country, const QString &
         localeLanguageCountry = localeLanguage.split(QLatin1Char('_')).at(1);
     }
 
-    QStringList regionList = KHolidays::HolidayRegion::regionCodes();
 
     QString countryAndLanguageMatch, countryOnlyMatch, subdivisionAndLanguageMatch,
             subdivisionOnlyMatch, languageCountryAndLanguageMatch, languageCountryOnlyMatch,
             languageSubdivisionAndLanguageMatch, languageSubdivisionOnlyMatch;
 
+    const QStringList regionList = KHolidays::HolidayRegion::regionCodes();
     foreach (const QString &regionCode, regionList) {
         QString regionCountry = KHolidays::HolidayRegion::countryCode(regionCode).toLower();
         QString regionSubdivisionCountry;
